.. -*- coding: utf-8 -*-

.. _`adk-transitions-FRODA-dataset`:


AdK FRODA transitions ensemble dataset
======================================

The macromolecular conformational transition between the closed
conformation of apo-adenylate kinase from E. coli (EcAdK) to the open
conformation was sampled with two methods: (1) dynamic importance
sampling molecular dynamics (DIMS MD) [Perilla2009]_, and (2)
Framework Rigidity Optimized Dynamics Algorithm (FRODA)
[Farrell2010]_. Each ensemble of independently generated paths
contains 200 trajectories in the CHARMM DCD format.

This data set contains the **FRODA** ensemble.

FRODA AdK with geometric targeting on a rigid decomposition (FRODA
server); closed (1AKE) to open (4AKE). Topology file: 1ake.pdb
(without hydrogens)

Notes
-----

Data set characteristics:

 :size: 539 MB
 :number of trajectories:  200	
 :number of frames:  varies
 :number of atoms: 1656
 :creator: Avishek Kumar
 :URL:  `https://doi.org/10.6084/m9.figshare.7165306.v2 <https://doi.org/10.6084/m9.figshare.7165306.v2>`_
 :license: `CC-BY 4.0 <https://creativecommons.org/licenses/by/4.0/legalcode>`_
 :reference: [Seyler2015]_
    

[Seyler2015] Seyler SL, Kumar A, Thorpe MF, Beckstein O (2015) Path
	     Similarity Analysis: A Method for Quantifying
	     Macromolecular Pathways. PLoS Comput Biol 11(10):
	     e1004568. https://doi.org/10.1371/journal.pcbi.1004568

